← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~allenap/maas/switch-ports into lp:maas

 

Gavin Panella has proposed merging lp:~allenap/maas/switch-ports into lp:maas.

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~allenap/maas/switch-ports/+merge/97764
-- 
https://code.launchpad.net/~allenap/maas/switch-ports/+merge/97764
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~allenap/maas/switch-ports into lp:maas.
=== modified file 'HACKING.txt'
--- HACKING.txt	2012-03-15 13:58:32 +0000
+++ HACKING.txt	2012-03-15 22:45:23 +0000
@@ -162,7 +162,7 @@
 
     $ make run
 
-Point your browser to http://localhost:8000/
+Point your browser to http://localhost:5240/
 
 If you've populated your instance with the sample data, you can login as a
 simple user using the test account (username: 'test', password: 'test') or the

=== modified file 'Makefile'
--- Makefile	2012-03-15 13:57:14 +0000
+++ Makefile	2012-03-15 22:45:23 +0000
@@ -102,7 +102,7 @@
 	{ test -e $(pidfile) && cat $(pidfile); } | xargs --no-run-if-empty kill
 
 run: bin/maas dev-db run/pserv.pid run/txlongpoll.pid
-	bin/maas runserver 0.0.0.0:8000 --settings=maas.demo
+	bin/maas runserver 0.0.0.0:5240 --settings=maas.demo
 
 harness: bin/maas dev-db
 	bin/maas shell --settings=maas.demo

=== modified file 'etc/pserv.yaml'
--- etc/pserv.yaml	2012-03-14 15:58:07 +0000
+++ etc/pserv.yaml	2012-03-15 22:45:23 +0000
@@ -4,7 +4,7 @@
 
 ## The port on which the Provisioning API will be made available.
 #
-# port: 8001
+# port: 5241
 
 ## Where to log. This log can be rotated by sending SIGUSR1 to the
 ## running server.

=== modified file 'etc/txlongpoll.yaml'
--- etc/txlongpoll.yaml	2012-03-14 16:59:25 +0000
+++ etc/txlongpoll.yaml	2012-03-15 22:45:23 +0000
@@ -6,7 +6,7 @@
 #
 frontend:
   ## The port on which to serve.
-  port: 8002
+  port: 5242
   ## If specified, queue names requested must have the given prefix.
   # prefix:
 

=== modified file 'src/maas/demo.py'
--- src/maas/demo.py	2012-03-15 17:30:53 +0000
+++ src/maas/demo.py	2012-03-15 22:45:23 +0000
@@ -33,14 +33,14 @@
 )
 
 # In dev mode: Django should act as a proxy to txlongpoll.
-LONGPOLL_SERVER_URL = "http://localhost:8002/";
+LONGPOLL_SERVER_URL = "http://localhost:5242/";
 
 # Disable longpoll by default for now. Set it back to 'longpoll/' to
 # enable it.
 LONGPOLL_PATH = None
 
 # This should match the setting in /etc/pserv.yaml.
-PSERV_URL = "http://localhost:8001/api";
+PSERV_URL = "http://localhost:5241/api";
 
 RABBITMQ_PUBLISH = True
 

=== modified file 'src/maas/development.py'
--- src/provisioningserver/plugin.py	2012-03-15 13:58:32 +0000
+++ src/provisioningserver/plugin.py	2012-03-15 22:45:23 +0000
@@ -89,7 +89,7 @@
 
     if_key_missing = None
 
-    port = Int(min=1, max=65535, if_missing=8001)
+    port = Int(min=1, max=65535, if_missing=5241)
     logfile = String(if_empty=b"pserv.log", if_missing=b"pserv.log")
     oops = ConfigOops
     broker = ConfigBroker

=== modified file 'src/provisioningserver/tests/test_api.py'
--- src/provisioningserver/tests/test_api.py	2012-03-14 11:50:36 +0000
+++ src/provisioningserver/tests/test_api.py	2012-03-15 22:45:23 +0000
@@ -76,7 +76,7 @@
 def fake_node_metadata():
     """Produce fake metadata parameters for adding a node."""
     return {
-        'maas-metadata-url': 'http://%s:8000/metadata/' % fake_name(),
+        'maas-metadata-url': 'http://%s:5240/metadata/' % fake_name(),
         'maas-metadata-credentials': 'fake/%s' % fake_name(),
         }
 

=== modified file 'src/provisioningserver/tests/test_plugin.py'
--- src/provisioningserver/tests/test_plugin.py	2012-02-29 11:40:46 +0000
+++ src/provisioningserver/tests/test_plugin.py	2012-03-15 22:45:23 +0000
@@ -54,7 +54,7 @@
                 'directory': '',
                 'reporter': '',
                 },
-            'port': 8001,
+            'port': 5241,
             }
         observed = Config.to_python({})
         self.assertEqual(expected, observed)

=== modified file 'vdenv/TODO'
--- vdenv/TODO	2012-01-25 14:15:02 +0000
+++ vdenv/TODO	2012-03-15 22:45:23 +0000
@@ -3,7 +3,7 @@
 - improve the Domain objects
 - document
   - vinagre $(virsh vncdisplay node01)
-  - ssh -L 5901:localhost:5901 -L 8000:192.168.123.2:80
+  - ssh -L 5901:localhost:5901 -L 5240:192.168.123.2:80
   - start ssh connection to remote system with a bunch of ports
     forwarded for vnc connections and http to the zimmer box
      ssh -C home-jimbo \


Follow ups
--- src/maas/development.py	2012-03-15 16:53:46 +0000
+++ src/maas/development.py	2012-03-15 22:45:23 +0000
@@ -26,8 +26,8 @@
 # Extend base settings.
 import_settings(settings)
 
-# In development, django can be accessed directly on port 8000.
-DEFAULT_MAAS_URL = "http://%s:8000/"; % gethostname()
+# In development, django can be accessed directly on port 5240.
+DEFAULT_MAAS_URL = "http://%s:5240/"; % gethostname()
 
 # Use our custom test runner, which makes sure that a local database
 # cluster is running in the branch.

=== modified file 'src/provisioningserver/plugin.py'